==> deepin-calculator_5.7.12.orig.tar.gz: deepin-calculator-5.7.12/translations/deepin-calculator.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Clear all memory</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Clear history</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Select All</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Redo</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Paste</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculator</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Scientific</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programmer</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Clear memory item</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Clear all memory</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Memory recall</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Add to memory item</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Memory add</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Subtract from memory item</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Memory subtract</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Memory store</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Clear memory item</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Add to memory item</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Subtract from memory item</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>Nothing saved in memory</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Arithmetic shift</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logical shift</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Circular shift</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotate through carry circular shift</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Arithmetic shift</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logical shift</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Circular shift</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotate through carry circular shift</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculator</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>History</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>No history</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.4.orig.tar.gz: deepin-calculator-6.5.4/translations/deepin-calculator.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Clear all memory</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Clear history</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Select All</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>Use thousands separator</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>Use ten-thousands separator</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Redo</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Paste</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculator</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Scientific</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programmer</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Clear memory item</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Clear all memory</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Memory recall</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Add to memory item</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Memory add</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Subtract from memory item</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Memory subtract</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Memory store</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Clear memory item</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Add to memory item</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Subtract from memory item</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>Nothing saved in memory</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Arithmetic shift</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logical shift</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Circular shift</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotate through carry circular shift</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Arithmetic shift</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Logical shift</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Circular shift</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Rotate through carry circular shift</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculator</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>History</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Expression error</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>No history</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
</TS>
